//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by Setup.rc
//
#define IDR_COMREG                      10
#define IDR_LANG_AR                     20
#define IDR_LANG_CS                     21
#define IDR_LANG_DE                     22
#define IDR_LANG_ES                     23
#define IDR_LANG_FR                     24
#define IDR_LANG_IT                     25
#define IDR_LANG_JA                     26
#define IDR_LANG_NL                     27
#define IDR_LANG_PL                     28
#define IDR_LANG_RO                     29
#define IDR_LANG_RU                     30
#define IDR_LANG_VI                     31
#define IDR_LANG_ZHCN                   32
#define IDR_LANG_ZHHK                   33
#define IDR_LANG_BE                     34
#define IDR_LANG_BG                     35
#define IDR_LANG_CA                     36
#define IDR_LANG_CO                     37
#define IDR_LANG_DA                     38
#define IDR_LANG_EL                     39
#define IDR_LANG_ET                     40
#define IDR_LANG_EU                     41
#define IDR_LANG_FA                     42
#define IDR_LANG_FI                     43
#define IDR_LANG_HE                     44
#define IDR_LANG_HU                     45
#define IDR_LANG_ID                     46
#define IDR_LANG_KA                     47
#define IDR_LANG_KO                     48
#define IDR_LANG_LV                     49
#define IDR_LANG_NN                     50
#define IDR_LANG_PTBR                   51
#define IDR_LANG_SK                     52
#define IDR_LANG_SL                     53
#define IDR_LANG_SV                     54
#define IDR_LANG_TH                     55
#define IDR_LANG_TR                     56
#define IDR_LANG_UK                     57
#define IDR_LANG_UZ                     58
#define IDR_LANG_ZHTW                   59
#define IDR_LANG_NB                     60
#define IDD_INSTALL                     101
#define IDD_INSTALL_OPTIONS_PAGE_DLG    102
#define IDD_UNINSTALL                   103
#define IDI_SETUP                       104
#define IDR_SETUP_RSRC_HEADER           105
#define IDD_EXTRACTION_OPTIONS_PAGE_DLG 106
#define IDB_SETUP_WIZARD                107
#define IDD_INTRO_PAGE_DLG              108
#define IDB_SETUP_WIZARD_BKG            109
#define IDD_INFO_PAGE_DLG               110
#define IDD_INSTL_DLG                   111
#define IDD_WIZARD_MODE_PAGE_DLG        112
#define IDD_PROGRESS_PAGE_DLG           113
#define IDD_DONATIONS_PAGE_DLG          114
#define IDD_INSTALL_LANGUAGE            115
#define IDC_DESTINATION                 1000
#define IDC_BOX_TITLE                   1001
#define IDC_BROWSE                      1002
#define IDC_BOX_INFO                    1003
#define IDC_LICENSE                     1004
#define IDC_BOX_HELP                    1005
#define IDC_LICENSE_TEXT                1006
#define IDC_BOX_HELP2                   1007
#define IDC_FILE_TYPE                   1008
#define IDT_UNINSTALL_DIR               1009
#define IDC_PROG_GROUP                  1010
#define IDC_SYSTEM_RESTORE              1011
#define IDC_DESKTOP_ICON                1012
#define IDC_ALL_USERS                   1013
#define IDT_INSTALL_DESTINATION         1014
#define IDC_UNINSTALL                   1015
#define IDC_PROGRESS_BAR                1016
#define IDC_LOG_WINDOW                  1017
#define IDC_SETUP_WIZARD_BKG            1018
#define IDC_SETUP_WIZARD_GFX_AREA       1019
#define IDC_HR                          1020
#define IDC_OPEN_CONTAINING_FOLDER      1021
#define IDC_AGREE                       1022
#define IDC_HR_BOTTOM                   1023
#define IDC_WIZARD_MODE_INSTALL         1024
#define IDC_WIZARD_MODE_EXTRACT_ONLY    1025
#define IDC_NEXT                        1026
#define IDC_PREV                        1027
#define IDT_EXTRACT_DESTINATION         1028
#define IDC_POS_BOX                     1029
#define IDC_BITMAP_SETUP_WIZARD         1030
#define IDC_MAIN_CONTENT_CANVAS         1031
#define IDC_DONATE                      1032
#define IDC_LANGUAGES_LIST              1033
#define IDC_SELECT_LANGUAGE_LABEL       1034
#define IDC_DISABLE_SCREEN_PROTECTION   1181

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        116
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1035
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
